#!/usr/bin/python
#
# Copyright (C) 2012, Canonical Ltd (http://www.canonical.com/)
#
# This file is part of ubuntu-test-cases.
#
# ubuntu-test-cases is free software: you can redistribute it
# and/or modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation, either version 3 of
# the License, or (at your option) any later version.
#
# ubuntu-test-cases is distributed in the hope that it will
# be useful, but WITHOUT ANY WARRANTY; without even the implied warranty
# of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with ubuntu-test-cases.  If not, see
# <http://www.gnu.org/licenses/>.

"""Check that root partition isn't completely full.

Note: There isn't any threshold defined, any value below 100% usage would be
considered as a pass.

"""

import logging
import unittest
import subprocess
import re


class DiskNotFullTest(unittest.TestCase):

    def test_disk_not_full(self):
        """Check that root partition isn't completely full."""
        logging.info('Getting disk usage...')
        process = subprocess.Popen('df', stdout=subprocess.PIPE)
        stdout, _stderr = process.communicate()
        logging.info('Disk usage:\n{}'.format(stdout))
        logging.info('Parsing root partition usage...')
        root_line = next(line for line in stdout.splitlines()
                         if line.endswith('/'))
        use_str = root_line.split()[4]
        match = re.match('(\d+)%', use_str)
        self.assertTrue(match,
                        "Unable to parse root partition use percentage: {}"
                        .format(use_str))
        use = int(match.group(1))
        logging.info('Root partition usage is: {}%'.format(use))
        self.assertLess(use, 100,
                        'Root filesystem must *not* be full after install')

if __name__ == '__main__':
    logging.basicConfig(level=logging.DEBUG,
                        format='%(levelname)s: %(message)s')
    unittest.main()
