#!/usr/bin/python
#
# Copyright (C) 2012, Canonical Ltd (http://www.canonical.com/)
#
# This file is part of ubuntu-test-cases.
#
# ubuntu-test-cases is free software: you can redistribute it
# and/or modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation, either version 3 of
# the License, or (at your option) any later version.
#
# ubuntu-test-cases is distributed in the hope that it will
# be useful, but WITHOUT ANY WARRANTY; without even the implied warranty
# of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with ubuntu-test-cases.  If not, see
# <http://www.gnu.org/licenses/>.

"""OEM packages are installed."""

import logging
import unittest
import apt


class OemPkgInstalled(unittest.TestCase):
    PACKAGE_NAMES = ('oem-config', 'oem-config-gtk')

    def test_oem_pkg_intalled(self):
        """OEM packages are installed."""
        logging.info('Getting apt cache...')
        cache = apt.cache.Cache()

        def check_installed(package_name):
            """
            Check a single package
            """
            logging.info('Checking if {!r} is in cache...'
                         .format(package_name))
            if package_name not in cache:
                logging.error('{!r} not found in the cache'
                              .format(package_name))
                return False

            logging.info('Checking if {!r} is installed...'
                         .format(package_name))
            package = cache[package_name]
            if not package.is_installed:
                logging.error('{!r} is not installed'
                              .format(package_name))
                return False
            return True

        installed = [check_installed(package_name)
                     for package_name in self.PACKAGE_NAMES]
        if not all(installed):
            raise AssertionError('Not all packages have been found '
                                 'and are installed')


if __name__ == '__main__':
    logging.basicConfig(level=logging.DEBUG,
                        format='%(levelname)s: %(message)s')
    unittest.main()
